%% code to run monte carlo simulations to test various hypotheses related
%% to color dominance
% produces heat maps from figure A4
clear all; clc; close all;

sim = 1; % 1 for local "zones" sim; 2 for "global" sim
plotit = 1; % 1 to produce heat map plots (fig. A4)

cd(fileparts(mfilename('fullpath')))
currdir = pwd;
num_bootstrap = 10000;
RT_allow = 0.3;

subjIDs = ['01';'02';'03';'04';'05';'06';'07';'08';'09';'10';'11';'12';'13';'14';'15';'16';'17';'18';'19';'20';'21';'22';'23';'24';'25';'26';'27';];

%% setup pools of dominance durations
pool_global = cell(size(subjIDs,1),1); % pool of red & green dominance durations for each subject, both eye pooled together across locations
pool_color = cell(size(subjIDs,1),2); % pool of dominance durations across all locations, but separately for red & green
pool_zones = cell(13,size(subjIDs,1),2); % durations pooled separately for each location and color

% for duration analyses
trial_durs = zeros(13,size(subjIDs,1),2);

locationorder = zeros(26,size(subjIDs,1),2);
configorder = zeros(26,size(subjIDs,1),2);
for SJ = 1:size(subjIDs,1)
    
    %% first analyze first run for each subject
    
    eval(['load ', currdir, '/Data_Maps_SED', subjIDs(SJ,:)]);
    locationorder(:,SJ,1) = MapsData{1}.params.locorder;
    
    if SJ == 17 % this subject, after run 1, told us that he had been pressing left arrow for red and right arrow for green, the opposite of what all other subjects did.
        Redkey = -1;
        Greenkey = 1;
    else
        Redkey = 1;
        Greenkey = -1;
    end
    
    for i = 1:length(MapsData)
        trial_durs(locationorder(i,SJ,1),SJ,1) = trial_durs(locationorder(i,SJ,1),SJ,1) + 60 + MapsData{i}.overtime;
        for n = 1:size(MapsData{i}.Times,1)-1
            if MapsData{i}.Times(n,2) == Greenkey
                if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                    pool_global{SJ}(size(pool_global{SJ},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    pool_color{SJ,1}(size(pool_color{SJ,1},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    pool_zones{locationorder(i,SJ,1),SJ,1}(size(pool_zones{locationorder(i,SJ,1),SJ,1},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                end
            elseif MapsData{i}.Times(n,2) == Redkey
                if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                    pool_global{SJ}(size(pool_global{SJ},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    pool_color{SJ,2}(size(pool_color{SJ,2},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    pool_zones{locationorder(i,SJ,1),SJ,2}(size(pool_zones{locationorder(i,SJ,1),SJ,2},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                end
            end
        end
    end
    clear MapsData
    
    %% repeat analysis for run 2
    if SJ ~= 9 && SJ ~= 11 % these two subjects did not complete the second session
        eval(['load ', currdir, '/Data_Maps_SED', subjIDs(SJ,:),'_2']);
        locationorder(:,SJ,2) = MapsData{1}.params.locorder;
        
        Redkey = 1;
        Greenkey = -1;
        
        for i = 1:length(MapsData)
            trial_durs(locationorder(i,SJ,1),SJ,1) = trial_durs(locationorder(i,SJ,1),SJ,1) + 60 + MapsData{i}.overtime;
            for n = 1:size(MapsData{i}.Times,1)-1
                if MapsData{i}.Times(n,2) == Greenkey
                    if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                        pool_global{SJ}(size(pool_global{SJ},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        pool_color{SJ,1}(size(pool_color{SJ,1},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        pool_zones{locationorder(i,SJ,2),SJ,1}(size(pool_zones{locationorder(i,SJ,2),SJ,1},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    end
                elseif MapsData{i}.Times(n,2) == Redkey
                    if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                        pool_global{SJ}(size(pool_global{SJ},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        pool_color{SJ,2}(size(pool_color{SJ,2},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        pool_zones{locationorder(i,SJ,2),SJ,2}(size(pool_zones{locationorder(i,SJ,2),SJ,2},1)+1,1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    end
                end
            end
        end
        clear MapsData
    end
end

%% compute global and local eye dominance for each subject from pooled data
for SJ = 1:size(subjIDs,1)
    STIMglobal(SJ) = (sum(pool_color{SJ,2})-sum(pool_color{SJ,1}))/(sum(pool_color{SJ,2})+sum(pool_color{SJ,1}));
    for locs = 1:13
        STIMlocal(locs,SJ) = (sum(pool_zones{locs,SJ,2})-sum(pool_zones{locs,SJ,1}))/(sum(pool_zones{locs,SJ,2})+sum(pool_zones{locs,SJ,1}));
    end
end

if sim == 1
    %% simulation #1: local eye dominance zones
    % first, for each subject draw 10,000 samples of SED based on the pooled LE
    % and RE durations ("pool_color"). This is done 13 times, each time with
    % the # of LE and RE durations matched to the number of observations for
    % that location
    STIM = zeros(size(subjIDs,1),num_bootstrap,13);
    edges = -1:0.05:1;
    STIM_hist = zeros(size(subjIDs,1),size(edges,2),13);
    for SJ = 1:size(subjIDs,1)
        SJ
        tmpL = pool_color{SJ,1};     tmpR = pool_color{SJ,2};
        for loc = 1:13
            nL = size(pool_zones{loc,SJ,1},1); % drawing samples that are the same size as measured samples
            nR = size(pool_zones{loc,SJ,2},1);
            for i = 1:num_bootstrap
                sL = sum(tmpL(Randi(nL,[1 nL])));
                sR = sum(tmpR(Randi(nR,[1 nR])));
                
                pL = sL/(sL+sR); pR = sR/(sL+sR);
                
                STIM(SJ,i,loc) = (pR - pL)/(pL + pR);   % sample STIM
                
                clear pL pR sL sR
            end
            STIM_hist(SJ,:,loc) = histc(STIM(SJ,:,loc),edges);
            STIM_hist(SJ,:,loc) = STIM_hist(SJ,:,loc)/sum(STIM_hist(SJ,:,loc));
            clear nL nR
        end
        clear tmpL tmpR
    end
    
    % now z-score observed values to distributions obtained above
    zone_Zscore = zeros(13,size(subjIDs,1));
    for SJ = 1:size(subjIDs,1)
        for loc = 1:13
            subjMean(loc,SJ) = mean(STIM(SJ,:,loc));
            subjSD(loc,SJ) = std(STIM(SJ,:,loc));
            
            zone_Zscore(loc,SJ) = (STIMlocal(loc,SJ)-subjMean(loc,SJ))/subjSD(loc,SJ);
            Zscore_vector(13*(SJ-1)+loc) = zone_Zscore(loc,SJ);
        end
    end
    Zscore_vector(abs(Zscore_vector)>2.9);
end

if sim == 2
    %% simulation #2: global eye dominance
    % first, for each subject draw 10,000 LE and RE samples from the global
    % pool of all durations for that subject
    STIM = zeros(size(subjIDs,1),num_bootstrap);
    edges = -1:0.05:1;
    STIM_hist = zeros(size(subjIDs,1),size(edges,2));
    for SJ = 1:size(subjIDs,1)
        SJ
        tmp = pool_global{SJ};
        nL = size(pool_color{SJ,1},1); % drawing samples that are the same size as measured samples
        nR = size(pool_color{SJ,2},1);
        for i = 1:num_bootstrap
            sL = sum(tmp(Randi(nL,[1 nL])));
            sR = sum(tmp(Randi(nR,[1 nR])));
            
            pL = sL/(sL+sR); pR = sR/(sL+sR);
            
            STIM(SJ,i) = (pR - pL)/(pL + pR);   % sample STIM
            
            clear pL pR sL sR
        end
        STIM_hist(SJ,:) = histc(STIM(SJ,:),edges);
        STIM_hist(SJ,:) = STIM_hist(SJ,:)/sum(STIM_hist(SJ,:));
        clear nL nR tmpL tmpR
    end
    
    % now z-score observed values to distributions obtained above
    global_Zscore = zeros(size(subjIDs,1),1);
    for SJ = 1:size(subjIDs,1)
        subjMean(SJ) = mean(STIM(SJ,:));
        subjSD(SJ) = std(STIM(SJ,:));
        
        global_Zscore(SJ) = (STIMglobal(SJ)-subjMean(SJ))/subjSD(SJ);
    end
    global_Zscore(abs(global_Zscore)>3);
end


%% make z-score heat maps
clear locs
pixperdegree = 45.73;
xc = round(10*pixperdegree/2); yc = round(10*pixperdegree/2);

locs(1,:) = [0 1.25 1.25 1.25 1.25 2.5 2.5 2.5 2.5 2.5 2.5 2.5 2.5];
locs(2,:) = [0 0 90 180 270 0 90 180 270 45 135 225 315]; % ORDER DIFFERS FROM OTHER CODE!!!
locs(2,:) = (locs(2,:)+180)*(pi/180);

if plotit
    for SJ = 1:27
        figure;
        for i = 1:length(locs)
            [x(i) y(i)] = pol2cart(locs(2,i),locs(1,i)*pixperdegree);
            if i == 1
                gauss1(:,:,i) = fspecial('disk',round(pixperdegree*1.01/2));
            elseif i > 1 && i < 6
                gauss2(:,:,i-1) = fspecial('disk',round(pixperdegree*1.4/2));
            elseif i > 5
                gauss3(:,:,i-5) = fspecial('disk',round(pixperdegree*1.96/2));
            end
        end
        gauss1(gauss1~=0) = 1;
        gauss2(gauss2~=0) = 1;
        gauss3(gauss3~=0) = 1;
        
        basemap = NaN(round(10*pixperdegree),round(10*pixperdegree),13);
        for i = 1:length(locs)
            if i == 1
                basemap(round(yc+y(i))-round(pixperdegree*1.01/2):round(yc+y(i))+round(pixperdegree*1.01/2),round(xc+x(i))-round(pixperdegree*1.01/2):round(xc+x(i))+round(pixperdegree*1.01/2),i) = gauss1(:,:,i);
            elseif i>1 && i < 6
                basemap(round(yc+y(i))-round(pixperdegree*1.4/2):round(yc+y(i))+round(pixperdegree*1.4/2),round(xc+x(i))-round(pixperdegree*1.4/2):round(xc+x(i))+round(pixperdegree*1.4/2),i) = gauss2(:,:,i-1);
            elseif i > 5
                basemap(round(yc+y(i))-round(pixperdegree*1.96/2):round(yc+y(i))+round(pixperdegree*1.96/2),round(xc+x(i))-round(pixperdegree*1.96/2):round(xc+x(i))+round(pixperdegree*1.96/2),i) = gauss3(:,:,i-5);
            end
        end
        basemap(basemap==0) = NaN;
        basemap = nansum(basemap,3);
        basemap(basemap==0) = NaN;
        
        for i = 1:length(locs)
            if i == 1
                gauss1 = gauss1 * abs(zone_Zscore(i,SJ));
            elseif i > 1 && i < 6
                gauss2(:,:,i-1) = gauss2(:,:,i-1)*abs(zone_Zscore(i,SJ));
            elseif i > 5
                gauss3(:,:,i-5) = gauss3(:,:,i-5)*abs(zone_Zscore(i,SJ));
            end
        end
        
        Hmap = NaN(round(10*pixperdegree),round(10*pixperdegree),13);
        for i = 1:length(locs)
            if i == 1
                Hmap(round(yc+y(i))-round(pixperdegree*1.01/2):round(yc+y(i))+round(pixperdegree*1.01/2),round(xc+x(i))-round(pixperdegree*1.01/2):round(xc+x(i))+round(pixperdegree*1.01/2),i) = gauss1(:,:,i);
            elseif i>1 && i < 6
                Hmap(round(yc+y(i))-round(pixperdegree*1.4/2):round(yc+y(i))+round(pixperdegree*1.4/2),round(xc+x(i))-round(pixperdegree*1.4/2):round(xc+x(i))+round(pixperdegree*1.4/2),i) = gauss2(:,:,i-1);
            elseif i > 5
                Hmap(round(yc+y(i))-round(pixperdegree*1.96/2):round(yc+y(i))+round(pixperdegree*1.96/2),round(xc+x(i))-round(pixperdegree*1.96/2):round(xc+x(i))+round(pixperdegree*1.96/2),i) = gauss3(:,:,i-5);
            end
            
        end
        Hmap(Hmap==0) = NaN;
        Hmap = nansum(Hmap,3);
        Hmap(Hmap==0) = NaN;
        Hmap(basemap==2) = Hmap(basemap==2)/2;
        
        colormap(winter)
        imagesc(Hmap,[0 5])
        hold on
        [r,c] = find(isnan(Hmap));
        hold on
        plot(c, r, 'wo')
        colorbar
        set(gca,'XTick',[0:pixperdegree:10*pixperdegree]);
        set(gca,'YTick',[0:pixperdegree:10*pixperdegree]);
        
        set(gca,'XTickLabel',[-5:1:5])
        set(gca,'YTickLabel',[-5:1:5])
        
        set(gca,'Xcolor',[0 0 0]);
        set(gca,'Ycolor',[0 0 0]);
        %         grid on
        %     imwrite(Hmap,num2str(SJ),'tiff')
    end
end







