%% main analysis for MAPS data
% code by Kevin C. Dieter, 2017, for "Persistent biases in binocular
% rivalry dynamics within the visual field"
% figs. 1 & 5 from paper

clear all; clc; close all;

cd(fileparts(mfilename('fullpath')))
currdir = pwd;
RT_allow = 0.3;
plotmaps = 1; % somewhat slow; 1 displays heatmap plots
plotFig4 = 0; % generate 2 plots corresponding to Fig. 4 in paper - NOTE these will come before heatmaps
SEDheatmaps = 1; % 1 = heat maps based on SED; 0 = heat maps based on STIM (color)

%% psychophysics subjects
subjIDs = ['01';'02';'03';'04';'05';'06';'07';'08';'09';'10';'11';'12';'13';'14';'15';'16';'17';'18';'19';'20';'21';'22';'23';'24';'25';'26';'27';];

% for duration analyses
le_block = cell(13,size(subjIDs,1)); re_block = cell(13,size(subjIDs,1)); be_block = cell(13,size(subjIDs,1));
ls_block = cell(13,size(subjIDs,1)); rs_block = cell(13,size(subjIDs,1)); bs_block = cell(13,size(subjIDs,1));
firstEYE = zeros(13,size(subjIDs,1));
firstSTIM = zeros(13,size(subjIDs,1));
trial_durs = zeros(13,size(subjIDs,1),2);
% for FRT analyses
FRT = zeros(13,7,length(subjIDs));

locationorder = zeros(26,size(subjIDs,1),2);
configorder = zeros(26,size(subjIDs,1),2);
for SJ = 1:size(subjIDs,1)
    
    %% first analyze first run for each subject
    eyecount = zeros(3,13);
    stimcount = zeros(3,13);
    
    eval(['load ', currdir, '/Data_Maps_SED', subjIDs(SJ,:)]);
    
    locationorder(:,SJ,1) = MapsData{1}.params.locorder;
    
    if SJ == 17 % this subject, after run 1, told us that he had been pressing left arrow for red and right arrow for green, the opposite of what all other subjects did.
        LEkey = -1;
        REkey = 1;
    else
        LEkey = 1;
        REkey = -1;
    end
    
    for i = 1:length(MapsData)
        trial_durs(locationorder(i,SJ,1),SJ,1) = trial_durs(locationorder(i,SJ,1),SJ,1) + 60 + MapsData{i}.overtime;
        
        % record first exclusive percept by EYE and STIMulus
        if MapsData{i}.Times(1,3) ~= 0
            if MapsData{i}.Times(1,3) == LEkey
                firstEYE(locationorder(i,SJ,1),SJ) = firstEYE(locationorder(i,SJ,1),SJ) + 1;
                firstSTIM(locationorder(i,SJ,1),SJ) = firstSTIM(locationorder(i,SJ,1),SJ) + 1;
            end
        elseif MapsData{i}.Times(2,3) ~= 0
            if MapsData{i}.Times(2,3) == LEkey
                firstEYE(locationorder(i,SJ,1),SJ) = firstEYE(locationorder(i,SJ,1),SJ) + 1;
                firstSTIM(locationorder(i,SJ,1),SJ) = firstSTIM(locationorder(i,SJ,1),SJ) + 1;
            end
        end
        
        % create cell arrays of duration data broken down by
        % eye(le/re) and mixture(be)
        for n = 1:size(MapsData{i}.Times,1)-1
            if MapsData{i}.Times(n,3) == LEkey
                if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                    le_block{locationorder(i,SJ,1),SJ}(eyecount(1,locationorder(i,SJ,1))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    eyecount(1,locationorder(i,SJ,1)) = eyecount(1,locationorder(i,SJ,1)) + 1;
                end
            elseif MapsData{i}.Times(n,3) == REkey
                if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                    re_block{locationorder(i,SJ,1),SJ}(eyecount(2,locationorder(i,SJ,1))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    eyecount(2,locationorder(i,SJ,1)) = eyecount(2,locationorder(i,SJ,1))+1;
                end
            elseif MapsData{i}.Times(n,3) == 0
                if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                    be_block{locationorder(i,SJ,1),SJ}(eyecount(3,locationorder(i,SJ,1))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    eyecount(3,locationorder(i,SJ,1)) = eyecount(3,locationorder(i,SJ,1))+1;
                end
            end
            
            % create cell arrays of duration data broken down by color;
            % green = ls; red = rs; mixture (bs)
            if MapsData{i}.Times(n,2) == -1
                if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                    ls_block{locationorder(i,SJ,1),SJ}(stimcount(1,locationorder(i,SJ,1))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    stimcount(1,locationorder(i,SJ,1)) = stimcount(1,locationorder(i,SJ,1))+1;
                end
            elseif MapsData{i}.Times(n,2) == 1
                if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                    rs_block{locationorder(i,SJ,1),SJ}(stimcount(2,locationorder(i,SJ,1))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    stimcount(2,locationorder(i,SJ,1)) = stimcount(2,locationorder(i,SJ,1))+1;
                end
            elseif MapsData{i}.Times(n,2) == 0
                if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                    bs_block{locationorder(i,SJ,1),SJ}(stimcount(3,locationorder(i,SJ,1))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                    stimcount(3,locationorder(i,SJ,1)) = stimcount(3,locationorder(i,SJ,1))+1;
                end
            end
            
        end
        
        %% now look at FRT (fraction of return transitions)
        riv_seq = [0;0]; riv_seq_count = 1;
        for n = 2:size(MapsData{i}.Times,1)
            riv_seq(1,riv_seq_count) = MapsData{i}.Times(n-1,3);
            riv_seq(2,riv_seq_count) = MapsData{i}.Times(n,1)-MapsData{i}.Times(n-1,1);
            riv_seq_count = riv_seq_count + 1;
        end
        
        riv_seq = riv_seq(:,riv_seq(2,:) > RT_allow); % filter percepts less than RT_allow
        
        percept = 1;
        while percept < size(riv_seq,2)-2
            if riv_seq(1,percept) ~=0 && riv_seq(1,percept+1)==0 && riv_seq(1,percept+2) == riv_seq(1,percept)
                FRT(locationorder(i,SJ,1),1,SJ) = FRT(locationorder(i,SJ,1),1,SJ)+1; % total return transitions
                if riv_seq(1,percept) == 1
                    FRT(locationorder(i,SJ,1),2,SJ) = FRT(locationorder(i,SJ,1),2,SJ)+1; % LE return transitions
                elseif riv_seq(1,percept) == -1
                    FRT(locationorder(i,SJ,1),3,SJ) = FRT(locationorder(i,SJ,1),3,SJ)+1; % RE return transitions
                end
            end
            percept = percept + 1;
        end
        
        riv_seq = riv_seq(:,riv_seq(1,:) ~= 0); % now filter out mixtures
        for n = 2:size(riv_seq,2)
            if riv_seq(1,n) ~= riv_seq(1,n-1)
                FRT(locationorder(i,SJ,1),4,SJ) = FRT(locationorder(i,SJ,1),4,SJ) + 1; % total non-return transitions
            end
        end
    end
    clear MapsData
    
    %% repeat analysis for run 2
    if SJ ~= 9 && SJ ~= 11 % these two subjects did not complete the second session
        eval(['load ', currdir, '/Data_Maps_SED', subjIDs(SJ,:),'_2']);
        locationorder(:,SJ,2) = MapsData{1}.params.locorder;
        
        LEkey = 1;
        REkey = -1;
        
        for i = 1:length(MapsData)
            trial_durs(locationorder(i,SJ,2),SJ,2) = trial_durs(locationorder(i,SJ,2),SJ,2) + 60 + MapsData{i}.overtime;
            configorder(i,SJ,2) = MapsData{i}.config;
            
            % record first exclusive percept by EYE and STIMulus
            if MapsData{i}.Times(1,3) ~= 0
                if MapsData{i}.Times(1,3) == LEkey
                    firstEYE(locationorder(i,SJ,2),SJ) = firstEYE(locationorder(i,SJ,2),SJ) + 1;
                    firstSTIM(locationorder(i,SJ,2),SJ) = firstSTIM(locationorder(i,SJ,2),SJ) + 1;
                end
            elseif MapsData{i}.Times(2,3) ~= 0
                if MapsData{i}.Times(2,3) == LEkey
                    firstEYE(locationorder(i,SJ,2),SJ) = firstEYE(locationorder(i,SJ,2),SJ) + 1;
                    firstSTIM(locationorder(i,SJ,2),SJ) = firstSTIM(locationorder(i,SJ,2),SJ) + 1;
                end
            end
            
            % create cell arrays of duration data broken down by
            % eye(le/re) and mixture(be)
            for n = 1:size(MapsData{i}.Times,1)-1
                % block by block analysis
                if MapsData{i}.Times(n,3) == LEkey
                    if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                        le_block{locationorder(i,SJ,2),SJ}(eyecount(1,locationorder(i,SJ,2))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        eyecount(1,locationorder(i,SJ,2)) = eyecount(1,locationorder(i,SJ,2))+1;
                    end
                elseif MapsData{i}.Times(n,3) == REkey
                    if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                        re_block{locationorder(i,SJ,2),SJ}(eyecount(2,locationorder(i,SJ,2))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        eyecount(2,locationorder(i,SJ,2)) = eyecount(2,locationorder(i,SJ,2))+1;
                    end
                elseif MapsData{i}.Times(n,3) == 0
                    if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                        be_block{locationorder(i,SJ,2),SJ}(eyecount(3,locationorder(i,SJ,2))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        eyecount(3,locationorder(i,SJ,2)) = eyecount(3,locationorder(i,SJ,2))+1;
                    end
                end
                
                % create cell arrays of duration data broken down by color;
                % green = ls; red = rs; mixture (bs)
                if MapsData{i}.Times(n,2) == -1
                    if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                        ls_block{locationorder(i,SJ,2),SJ}(stimcount(1,locationorder(i,SJ,2))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        stimcount(1,locationorder(i,SJ,2)) = stimcount(1,locationorder(i,SJ,2))+1;
                    end
                elseif MapsData{i}.Times(n,2) == 1
                    if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                        rs_block{locationorder(i,SJ,2),SJ}(stimcount(2,locationorder(i,SJ,2))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        stimcount(2,locationorder(i,SJ,2)) = stimcount(2,locationorder(i,SJ,2))+1;
                    end
                elseif MapsData{i}.Times(n,2) == 0
                    if (MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1)) > RT_allow
                        bs_block{locationorder(i,SJ,2),SJ}(stimcount(3,locationorder(i,SJ,2))+1) = MapsData{i}.Times(n+1,1)-MapsData{i}.Times(n,1);
                        stimcount(3,locationorder(i,SJ,2)) = stimcount(3,locationorder(i,SJ,2))+1;
                    end
                end
            end
            
            %% now look at FRT
            riv_seq = [0;0]; riv_seq_count = 1;
            for n = 2:size(MapsData{i}.Times,1)
                riv_seq(1,riv_seq_count) = MapsData{i}.Times(n-1,3);
                riv_seq(2,riv_seq_count) = MapsData{i}.Times(n,1)-MapsData{i}.Times(n-1,1);
                riv_seq_count = riv_seq_count + 1;
            end
            
            riv_seq = riv_seq(:,riv_seq(2,:) > RT_allow); % filter percepts less than RT_allow
            
            percept = 1;
            while percept < size(riv_seq,2)-2
                if riv_seq(1,percept) ~=0 && riv_seq(1,percept+1)==0 && riv_seq(1,percept+2) == riv_seq(1,percept)
                    FRT(locationorder(i,SJ,2),1,SJ) = FRT(locationorder(i,SJ,2),1,SJ)+1; % total return transitions
                    if riv_seq(1,percept) == 1
                        FRT(locationorder(i,SJ,2),2,SJ) = FRT(locationorder(i,SJ,2),2,SJ)+1; % LE return transitions
                    elseif riv_seq(1,percept) == -1
                        FRT(locationorder(i,SJ,2),3,SJ) = FRT(locationorder(i,SJ,2),3,SJ)+1; % RE return transitions
                    end
                end
                percept = percept + 1;
            end
            
            riv_seq = riv_seq(:,riv_seq(1,:) ~= 0); % now filter out mixtures
            for n = 2:size(riv_seq,2)
                if riv_seq(1,n) ~= riv_seq(1,n-1)
                    FRT(locationorder(i,SJ,2),4,SJ) = FRT(locationorder(i,SJ,2),4,SJ) + 1; % total non-return transitions
                end
            end
        end
    end
    clear MapsData
    
    for i = 1:13
        altrate(i,SJ) = (eyecount(1,i)+eyecount(2,i)-1)/(trial_durs(i,SJ,1)+trial_durs(i,SJ,2));
    end
end

%% now compute SED
SED_run = zeros(13,size(subjIDs,1),2); SED_overall = zeros(13,size(subjIDs,1));
STIM_run = zeros(13,size(subjIDs,1),2); STIM_overall = zeros(13,size(subjIDs,1));
for SJ = 1:size(subjIDs,1)
    % both runs pooled
    for i = 1:13
        propLE(i,SJ) = nansum(le_block{i,SJ})/(nansum(le_block{i,SJ}) + nansum(re_block{i,SJ}) + nansum(be_block{i,SJ}));
        propRE(i,SJ) = nansum(re_block{i,SJ})/(nansum(le_block{i,SJ}) + nansum(re_block{i,SJ}) + nansum(be_block{i,SJ}));
        propBE(i,SJ) = nansum(be_block{i,SJ})/(nansum(le_block{i,SJ}) + nansum(re_block{i,SJ}) + nansum(be_block{i,SJ}));
        propLS(i,SJ) = nansum(ls_block{i,SJ})/(nansum(ls_block{i,SJ}) + nansum(rs_block{i,SJ}) + nansum(bs_block{i,SJ}));
        propRS(i,SJ) = nansum(rs_block{i,SJ})/(nansum(ls_block{i,SJ}) + nansum(rs_block{i,SJ}) + nansum(bs_block{i,SJ}));
        propBS(i,SJ) = nansum(bs_block{i,SJ})/(nansum(ls_block{i,SJ}) + nansum(rs_block{i,SJ}) + nansum(bs_block{i,SJ}));
        
        % now RE-LE/RE+LE, after Dieter, Sy & Blake Vis Res 2016
        SED_overall(i,SJ) = (propRE(i,SJ)-propLE(i,SJ))/(propRE(i,SJ)+propLE(i,SJ));
        STIM_overall(i,SJ) = (propLS(i,SJ)-propRS(i,SJ))/(propRS(i,SJ)+propLS(i,SJ));
        
        medLE(i,SJ) = nanmedian(le_block{i,SJ});
        medRE(i,SJ) = nanmedian(re_block{i,SJ});
        medBE(i,SJ) = nanmedian(be_block{i,SJ});
        medLS(i,SJ) = nanmedian(ls_block{i,SJ});
        medRS(i,SJ) = nanmedian(rs_block{i,SJ});
        medBS(i,SJ) = nanmedian(bs_block{i,SJ});
    end
end

%% finish up FRT analysis
for SJ = 1:size(subjIDs,1)
    FRT(:,4,SJ) = FRT(:,4,SJ) + FRT(:,1,SJ); % add total return transitions to total non-returns to get total transitions
    FRT(:,5,SJ) = FRT(:,1,SJ)./FRT(:,4,SJ); % total fraction of return transitions
    FRT(:,6,SJ) = FRT(:,2,SJ)./FRT(:,4,SJ); % FRT to LE
    FRT(:,7,SJ) = FRT(:,3,SJ)./FRT(:,4,SJ); % FRT to RE
end

%% compare total # of percepts to relative duration of percepts, see
%% Dieter, Sy, Blake under rev.
for SJ = 1:size(subjIDs,1)
    for i = 1:13
        LEtot(i,SJ) = size(le_block{i,SJ},2);
        REtot(i,SJ) = size(re_block{i,SJ},2);
        BEtot(i,SJ) = size(be_block{i,SJ},2);
        
        pctperceptdiff_NUM(i,SJ) = (LEtot(i,SJ)-REtot(i,SJ))/(LEtot(i,SJ)+REtot(i,SJ));
        pctperceptdiff_DUR(i,SJ) = (medLE(i,SJ)-medRE(i,SJ));
    end
end

%% concatenate everything into vectors for stats
for SJ = 1:size(subjIDs,1)
    SED_vector(13*(SJ-1)+1:13*SJ,1) = SED_overall(:,SJ);
    STIM_vector(13*(SJ-1)+1:13*SJ,1) = STIM_overall(:,SJ);
    FRTtot_vector(13*(SJ-1)+1:13*SJ,1) = FRT(:,5,SJ);
    FRTLE_vector(13*(SJ-1)+1:13*SJ,1) = FRT(:,6,SJ);
    FRTRE_vector(13*(SJ-1)+1:13*SJ,1) = FRT(:,7,SJ);
    altrate_vector(13*(SJ-1)+1:13*SJ,1) = altrate(:,SJ);
    mixprop_vector(13*(SJ-1)+1:13*SJ,1) = propBE(:,SJ);
    LEmed_vector(13*(SJ-1)+1:13*SJ,1) = medLE(:,SJ);
    REmed_vector(13*(SJ-1)+1:13*SJ,1) = medRE(:,SJ);
    LEtot_vector(13*(SJ-1)+1:13*SJ,1) = LEtot(:,SJ);
    REtot_vector(13*(SJ-1)+1:13*SJ,1) = REtot(:,SJ);
    firstEYE_vector(13*(SJ-1)+1:13*SJ,1) = firstEYE(:,SJ);
    firstSTIM_vector(13*(SJ-1)+1:13*SJ,1) = firstSTIM(:,SJ);
    
end

for n = 1:length(FRTLE_vector)
    if (FRTLE_vector(n) + FRTRE_vector(n) == 0)
        combined(n) = 0;
    else
        combined(n) = (FRTRE_vector(n)-FRTLE_vector(n))/(FRTRE_vector(n)+FRTLE_vector(n));
    end
end

%% generate figure 4?
if plotFig4
    figure;
    subplot(1,2,1)
    plot(SED_vector*100,REmed_vector-LEmed_vector,'ko')
    axis([-100 100 -4 4])
    title('Paper Figure 4a')
    xlabel('SED (%)')
    ylabel('RE - LE median percept duration (sec)')
    set(gca,'fontsize', 14)
    
    subplot(1,2,2)
    plot(SED_vector*100,combined*100,'ko')
    axis([-100 100 -100 100])
    title('Paper Figure 4b')
    xlabel('SED (%)')
    ylabel('% diff in FRT, RE-LE')
    set(gca,'fontsize', 14)
end


%% make heat maps
if plotmaps
    for SJ = 1:27
        pixperdegree = 45.73;
        xc = round(10*pixperdegree/2); yc = round(10*pixperdegree/2);
        figure;
        
        if SEDheatmaps == 1
            data = SED_overall(:,SJ);
        else
            data = STIM_overall(:,SJ);
        end
        locs(1,:) = [0 1.25 1.25 1.25 1.25 2.5 2.5 2.5 2.5 2.5 2.5 2.5 2.5];
        locs(2,:) = [0 0 90 180 270 0 90 180 270 45 135 225 315]; % ORDER DIFFERS FROM OTHER CODE!!!
        locs(2,:) = (locs(2,:)+180)*(pi/180);
        
        for i = 1:length(locs)
            [x(i) y(i)] = pol2cart(locs(2,i),locs(1,i)*pixperdegree);
            if i == 1
                gauss1(:,:,i) = fspecial('disk',round(pixperdegree*1.01/2));
            elseif i > 1 && i < 6
                gauss2(:,:,i-1) = fspecial('disk',round(pixperdegree*1.4/2));
            elseif i > 5
                gauss3(:,:,i-5) = fspecial('disk',round(pixperdegree*1.96/2));
            end
        end
        gauss1(gauss1~=0) = 1;
        gauss2(gauss2~=0) = 1;
        gauss3(gauss3~=0) = 1;
        
        basemap = NaN(round(10*pixperdegree),round(10*pixperdegree),13);
        for i = 1:length(locs)
            if i == 1
                basemap(round(yc+y(i))-round(pixperdegree*1.01/2):round(yc+y(i))+round(pixperdegree*1.01/2),round(xc+x(i))-round(pixperdegree*1.01/2):round(xc+x(i))+round(pixperdegree*1.01/2),i) = gauss1(:,:,i);
            elseif i>1 && i < 6
                basemap(round(yc+y(i))-round(pixperdegree*1.4/2):round(yc+y(i))+round(pixperdegree*1.4/2),round(xc+x(i))-round(pixperdegree*1.4/2):round(xc+x(i))+round(pixperdegree*1.4/2),i) = gauss2(:,:,i-1);
            elseif i > 5
                basemap(round(yc+y(i))-round(pixperdegree*1.96/2):round(yc+y(i))+round(pixperdegree*1.96/2),round(xc+x(i))-round(pixperdegree*1.96/2):round(xc+x(i))+round(pixperdegree*1.96/2),i) = gauss3(:,:,i-5);
            end
        end
        basemap(basemap==0) = NaN;
        basemap = nansum(basemap,3);
        basemap(basemap==0) = NaN;
        
        for i = 1:length(locs)
            if i == 1
                gauss1 = gauss1 * data(i);
            elseif i > 1 && i < 6
                gauss2(:,:,i-1) = gauss2(:,:,i-1)*data(i);
            elseif i > 5
                gauss3(:,:,i-5) = gauss3(:,:,i-5)*data(i);
            end
        end
        
        Hmap = NaN(round(10*pixperdegree),round(10*pixperdegree),13);
        for i = 1:length(locs)
            if i == 1
                Hmap(round(yc+y(i))-round(pixperdegree*1.01/2):round(yc+y(i))+round(pixperdegree*1.01/2),round(xc+x(i))-round(pixperdegree*1.01/2):round(xc+x(i))+round(pixperdegree*1.01/2),i) = gauss1(:,:,i);
            elseif i>1 && i < 6
                Hmap(round(yc+y(i))-round(pixperdegree*1.4/2):round(yc+y(i))+round(pixperdegree*1.4/2),round(xc+x(i))-round(pixperdegree*1.4/2):round(xc+x(i))+round(pixperdegree*1.4/2),i) = gauss2(:,:,i-1);
            elseif i > 5
                Hmap(round(yc+y(i))-round(pixperdegree*1.96/2):round(yc+y(i))+round(pixperdegree*1.96/2),round(xc+x(i))-round(pixperdegree*1.96/2):round(xc+x(i))+round(pixperdegree*1.96/2),i) = gauss3(:,:,i-5);
            end
            
        end
        Hmap(Hmap==0) = NaN;
        Hmap = nansum(Hmap,3);
        Hmap(Hmap==0) = NaN;
        Hmap(basemap==2) = Hmap(basemap==2)/2;
        
        if SEDheatmaps == 1
            colormap(jet)
            imagesc(Hmap,[-.4 .4])
        else
            map(:,1) = transpose(linspace(1,0,80));
            map(:,2) = transpose(linspace(0,1,80));
            map(:,3) = 0;
            colormap(map)
            imagesc(Hmap,[-.4 .4])
        end
        hold on
        [r,c] = find(isnan(Hmap));
        hold on
        plot(c, r, 'wo')
        colorbar
        title(['Observer S', num2str(SJ)])
        set(gca,'fontsize', 14)
        set(gca,'XTick',[0:pixperdegree:10*pixperdegree]);
        set(gca,'YTick',[0:pixperdegree:10*pixperdegree]);
        
        set(gca,'XTickLabel',[-5:1:5])
        set(gca,'YTickLabel',[-5:1:5])
        
        set(gca,'Xcolor',[0 0 0]);
        set(gca,'Ycolor',[0 0 0]);
        % grid on
        % imwrite(Hmap,num2str(SJ),'tiff')
    end
end


